@@ -1,14 +1,14 @@
 package Faker::Provider::PhoneNumber;
 
 use Bubblegum::Class;
-use Bubblegum::Syntax -types;
+use Bubblegum::Constraints -minimal;
 
 with 'Faker::Role::Data';
 with 'Faker::Role::Provider';
 
 around guesser => sub {
     my ($orig, $self, $format) =
-        (shift, type_obj(shift), type_str(shift));
+        (shift, _obj(shift), _str(shift));
 
     return 'phone_number' if $format =~ /^(phonenumber|phone|telephone)$/;
 
@@ -16,8 +16,8 @@ around guesser => sub {
 };
 
 sub phone_number {
-    my $self   = type_obj shift;
-    my $data   = type_href $self->data;
+    my $self   = _obj shift;
+    my $data   = _href $self->data;
     my $format = $self->random_item($data->{phone_number_data_formats});
     return $self->generator->parse($format);
 }
